==> gDesklets-0.12.tar.bz2: gDesklets-0.12/factory/SensorFactory.py <==
from main import HOME, SENSORPATHS
from config.ConfigManager import ConfigManager
from utils import singleton
from utils import dialog

from main import _

import os, sys


sys.path.append(".")
sys.path.append(HOME)



#
# Factory class for dynamically loaded Sensors.
#
class SensorFactory:

    def __init__(self):

        # a set to remember the modules loaded so far
        self.__modules = {}
        
        self.__config = singleton.get(ConfigManager)



    #
    # Creates and returns a Sensor of the given type or None if the Sensor
    # could not be created.
    #
    def create_sensor(self, name, args):

        # FIXME: I think the GConf key main/sensorpaths is obsolete now.
        #        Do we still need to read it?
        sensorpaths = self.__config.get("main", "sensorpaths")
        parts = sensorpaths.split(",")

        oldcwd = os.getcwd()
        sensor = None
        for p in SENSORPATHS + parts:
            try:
                os.chdir(p)

                # reload old modules to force using the latest version; this
                # means we can edit modules while running gDesklets
                if (self.__modules.has_key(name)):
                    module = self.__modules[name]
                    reload(module)
                else:
                    try:
                        module = __import__(name)
                    except StandardError, e:
                        #print e
                        pass
                    self.__modules[name] = module
                
            except:
                continue

            try:
                os.chdir(name)
                sensor = module.new_sensor(args)
                break
            except StandardError, e:
                print e
        #end for

        if (not sensor):
            print "Could not load sensor %(name)s" % vars()
            dialog.warning(_("Could not load sensor '%(name)s'") % vars(),
                           _("An error occured while loading a sensor. This "
                             "most likely means that the sensor is broken or "
                             "simply not installed."))
            
        os.chdir(oldcwd)
        return sensor

==> gDesklets-0.20.tar.bz2: gDesklets-0.20/factory/SensorFactory.py <==
from main import HOME, SENSORPATHS
from config.ConfigManager import ConfigManager
from utils import singleton
from utils import dialog

from main import _

import os, sys


sys.path.append(".")
sys.path.append(HOME)



#
# Factory class for dynamically loaded Sensors.
#
class SensorFactory:

    def __init__(self):

        # a set to remember the modules loaded so far
        self.__modules = {}
        
        self.__config = singleton.get(ConfigManager)



    #
    # Creates and returns a Sensor of the given type or None if the Sensor
    # could not be created.
    #
    def create_sensor(self, name, args):

        # FIXME: I think the GConf key main/sensorpaths is obsolete now.
        #        Do we still need to read it?
        sensorpaths = self.__config.get("main", "sensorpaths")
        parts = sensorpaths.split(",")

        oldcwd = os.getcwd()
        sensor = None
        for p in SENSORPATHS + parts:
            try:
                os.chdir(p)

                # reload old modules to force using the latest version; this
                # means we can edit modules while running gDesklets
                try:
                    if (self.__modules.has_key(name)):
                        module = self.__modules[name]
                        reload(module)
                        
                    else:
                        module = __import__(name)
                        
                except ImportError:
                    pass
                
                except StandardError, e:
                    # a stack trace could be useful for debugging sensors
                    import traceback; traceback.print_exc()
                    print e
                    
                self.__modules[name] = module
                
            except:
                continue

            try:
                os.chdir(name)
                sensor = module.new_sensor(args)
                break
            except StandardError, e:
                # a stack trace could be useful for debugging sensors
                import traceback; traceback.print_exc()
                print e
        #end for

        if (not sensor):
            print "Could not load sensor %(name)s" % vars()
            dialog.warning(_("Could not load sensor '%(name)s'") % vars(),
                           _("An error occured while loading a sensor. This "
                             "most likely means that the sensor is broken or "
                             "simply not installed."))
            
        os.chdir(oldcwd)
        return sensor
